@@ -30,6 +30,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 #include <glib.h>
+#include <gmime/gmime-error.h>
 #include <gmime/gmime-charset.h>
 #include <gmime/gmime-iconv.h>
 #include <gmime/gmime-iconv-utils.h>
@@ -66,7 +67,6 @@ extern "C" {
 #include <gmime/gmime-filter-html.h>
 #include <gmime/gmime-filter-strip.h>
 #include <gmime/gmime-filter-yenc.h>
-#include <gmime/gmime-exception.h>
 #include <gmime/gmime-session.h>
 #include <gmime/gmime-cipher-context.h>
 #include <gmime/gmime-gpg-context.h>
@@ -74,7 +74,7 @@ extern "C" {
 /* GMIME version */
 static const guint gmime_major_version = 1;
 static const guint gmime_minor_version = 90;
-static const guint gmime_micro_version = 4;
+static const guint gmime_micro_version = 6;
 static const guint gmime_interface_age = 0;
 static const guint gmime_binary_age    = 0;
 
